==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2206_162.zip: ronportal/ronportal/zamestnanci/seznamppbrowser.php <==
<?php

/**
 * Pavel Rudol, RON Software
 *  4.9.2015
 */

namespace RonPortal\Zamestnanci;

use Ron\DB\SqlStatement;
use RonPortal\Prava;
use RonPortal\RozdeleniUtils;


///**
// * Class IDMediumFilterForm
// * @package Ron\RonPortal\Zamestnanci
// */
//class IDMediumField extends BrowserField
//{
//    private $volnaMedia;
//    private $vyrazenaMedia;
//
//    /**
//     * IDMediumFilterForm constructor.
//     * @param Database $database
//     * @param bool $volnaMedia
//     * @param $vyrazenaMedia
//     */
//    function __construct($database, $volnaMedia, $vyrazenaMedia)
//    {
//        parent::__construct($database);
//
//        $this->volnaMedia = $volnaMedia;
//        $this->vyrazenaMedia = $vyrazenaMedia;
//        $this->header = \Ron\ronText('identifikacni_medium');
//        $this->align = 'center';
//        $this->ordering = 1;
//    }
//
//    function getViewText($value, $rowNumber, $recordId, $rowData)
//    {
//        $result = '';
//
//        if($rowData[8] != ''){
//
//            if($this->volnaMedia) {
//                $result .=
//                    //Zobrazi odkaz v pripade ze jiz je karta k dane osobe pridelena
//                    '<a href="?menuid=zamestnanec&action=prirazenikarty&formaction=edit&volnamedia=' . ($this->vyrazenaMedia ? 1 : 0) . '&osoba=' . $rowData[0] . '&kodkarty=' . $rowData[7] .
//                    '&datumprideleni=' . $this->database->stringToTimestamp($rowData[9]) . '" >';
//                $result .= $rowData[8];
//                $result .= '</a>';
//            } else {
//                $result .=
//                    //Zobrazi odkaz v pripade ze jiz je karta k dane osobe pridelena
//                    '<a title="' . \Ron\ronText('nejsou_dalsi_volna_media') . '" href="?menuid=zamestnanec&action=prirazenikarty&formaction=edit&volnamedia=' . ($this->vyrazenaMedia ? 1 : 0) . '&osoba=' . $rowData[0] . '&kodkarty=' . $rowData[7] .
//                    '&datumprideleni=' . $this->database->stringToTimestamp($rowData[9]) . '" >';
//                $result .= $rowData[8];
//                $result .= '</a>';
//            }
//
//        }else {
//            if ($this->volnaMedia) {
//                $result .=
//                    '<a href="?menuid=zamestnanec&action=prirazenikarty&formaction=new&volnamedia=' . ($this->vyrazenaMedia ? 1 : 0) . '&osoba=' . $rowData[0] . '" >';
//                $result .= \Ron\ronText('vydani_media');
//                $result .= '</a>';
//            } elseif ($this->vyrazenaMedia) {
//                //$vyrazenaMedia
//                $result .= '<a title="' . \Ron\ronText('nejsou_volna_nebo_obnovit') . '" href="?menuid=zamestnanec&action=obnovenimedia&formaction=edit">' . \Ron\ronText('nejsou_volna_media') . '</a>';
//            } else {
//                $result .= '';
//            }
//        }
//        return $result;
//    }
//}

class SeznamPPBrowser extends SeznamZamestnancuBrowser
{
    public function __construct($database, $action)
    {
        parent::__construct($database, $action, true); // pracovni pomer = true

        $this->code = 'browserppomery';
        $this->tableId = 'browserppomery';

        $this->browserUrl = '?menuid=zamestnanec&action=seznampp&';

        //TODO: nechat, nebo uplne presunout do formulare zamestnance?
        /*global $enable_seznamPP;
        if ($enable_seznamPP)
        $this->addField(new IDMediumField($this->database, $this->dotazNaVolnaMedia(), $this->dotazNaVyrazenaMedia()));*/

    }


    public function loadColumnConfiguration($colSettings)
    {
        // kontrola, jestli neni zobrazeni sloupce v seznamu osob vypnuto
        if (isset($colSettings['pracovnipomery'])  &&  !$colSettings['pracovnipomery']) {
            return;
        }

        parent::loadColumnConfiguration($colSettings);
    }


    function getSQLFilter()
    {
        $params = $this ->database ->createParameters();

        $result = '(' . $this->pravaZobrazit->sqlFiltr('PracovniPomer', time(), time(), $params) . ')';

        if ($this ->filterForm instanceof SeznamZamestnancuFilterForm) {
            switch ($this->filterForm->stavZamestnance) {
                case 'aktivni' :
                    $result .=
                        ' AND PracovniPomer.DatumNastupu <= ' . $params ->addDateParameter($this ->filterForm ->datumDo) .
                        ' AND ((PracovniPomer.DatumUkonceni >= ' . $params->addDateParameter($this ->filterForm ->datumOd) . ') OR (PracovniPomer.DatumUkonceni IS NULL))';
                    break;

                case 'neaktivni' :
                    $result .=
                        'AND PracovniPomer.DatumUkonceni IS NOT NULL' .
                        ' AND (PracovniPomer.DatumUkonceni <= ' . $params->addDateParameter($this ->filterForm ->datumOd) . ')';
                    break;

                default :
            }

            if (isset($this ->filterForm ->typZamestnance)) {
                $result .=
                    ' AND (PracovniPomer.Zamestnanec = ' . $params ->addParameter((int)$this ->filterForm ->typZamestnance) . ')';
            }
        }

        if ($this ->filterForm ->kodTypuRozdeleni  &&  isset($this ->filterForm ->kodRozdeleni)) {
            $filtrRozdeleni1 = RozdeleniUtils::sqlFilterRozdeleniPP($this->database, 'PracovniPomer',
                $this ->filterForm ->kodTypuRozdeleni, $this ->filterForm ->kodRozdeleni,
                $this ->filterForm ->datumOd ?: time(), $this ->filterForm ->datumDo ?: time(),
                $this ->filterForm ->vcetnePodrizenychRozdeleni,
                $params);

            if ($filtrRozdeleni1) {
                $result .=
                    ($result ? ' AND ' : '') .
                    $filtrRozdeleni1;
            }

        }

        if ($this ->filterForm ->kodTypuRozdeleni2  &&  isset($this ->filterForm ->kodRozdeleni2)) {
            $filtrRozdeleni2 = RozdeleniUtils::sqlFilterRozdeleniPP($this->database, 'PracovniPomer',
                $this ->filterForm ->kodTypuRozdeleni2, $this ->filterForm ->kodRozdeleni2,
                $this ->filterForm ->datumOd ?: time(), $this ->filterForm ->datumDo ?: time(),
                $this ->filterForm ->vcetnePodrizenychRozdeleni2,
                $params);

            if ($filtrRozdeleni2) {
                $result .=
                    ($result ? ' AND ' : '') .
                    $filtrRozdeleni2;
            }

        }
//        if (RonPortalSettings::getIntValue(RonPortalSettings::ROZDELENI_TYP) != 0)
//            $result .= (RonPortalSession::rozdeleni() != '' ? 'AND ' . $this->getSQLFilterRozdeleni(RonPortalSettings::getIntValue(RonPortalSettings::ROZDELENI_TYP), RonPortalSession::rozdeleni(), RonPortalSession::rozdeleniVcetnePodrizenych()) : '');
//        if (RonPortalSettings::getIntValue(RonPortalSettings::ROZDELENI2_TYP) != 0)
//            $result .= (RonPortalSession::rozdeleni2() != '' ? 'AND ' . $this->getSQLFilterRozdeleni(RonPortalSettings::getIntValue(RonPortalSettings::ROZDELENI2_TYP), RonPortalSession::rozdeleni2(), RonPortalSession::rozdeleni2VcetnePodrizenych()) : '');

        return new SqlStatement($result, $params);
    }

//    /**
//     * @return bool
//     * @throws DBException
//     */
//    function dotazNaVolnaMedia()
//    {
//        $sql =
//            "SELECT  Karta.Kod, Karta.OznaceniMedia  FROM Karta LEFT JOIN S_ZpusobVyrazeniKarty ON (Karta.ZpusobVyrazeni = S_ZpusobVyrazeniKarty.Kod)" .
//            "WHERE DatumPorizeni <= " . $this->database->timestampToString(time()) .
//            "  AND (DatumVyrazeni >= " . $this->database->timestampToString(time()) . " OR DatumVyrazeni IS NULL)" .
//            " AND NOT EXISTS(SELECT kodKarty FROM PrirazeniKarty WHERE kodKarty = Karta.kod AND datumPrideleni <= " . $this->database->timestampToString(time()) .
//            "  AND (datumVraceni >= " . $this->database->timestampToString(time()) . " OR datumVraceni IS NULL))";
//
//        $cursor = $this->database->getSqlResult($sql);
//        $row = $cursor->fetch();
//
//        if (!$row) {
//            return false;
//        }
//        return true;
//    }
//
//    /**
//     * @return bool
//     * @throws DBException
//     */
//    function dotazNaVyrazenaMedia()
//    {
//        $sql =
//            'SELECT * FROM Karta WHERE DatumVyrazeni IS NOT NULL';
//
//        $cursor = $this->database->getSqlResult($sql);
//        $row = $cursor->fetch();
//
//        if (!$row) {
//            return false;
//        }
//        return true;
//    }

//    /**
//     *
//     * @param integer $typRozdeleni Typ rozdeleni pro filtrovani
//     * @param string $rozdeleni kod rozdeleni pro filtrovani
//     * @param int $vcetnePodrizenych 0=jen vlastni, 1=vcetne podrizenych, 2=jen podrizene, 3=jen primo podrizene
//     * @return string SQL podminka existence prirazeneho rozdeleni
//     */
//    function getSQLFilterRozdeleni($typRozdeleni, $rozdeleni, $vcetnePodrizenych)
//    {
//        $sqlPodrizene = '';
//
//        switch ($vcetnePodrizenych) {
//            case 0:
//                $sqlPodrizene = 'and (HierarchieRozdeleni.kodNadrazene = HierarchieRozdeleni.kodPodrizene) ';
//                break;
//            case 1:
//                $sqlPodrizene = '';
//                break;
//            case 2:
//                $sqlPodrizene = 'and (HierarchieRozdeleni.kodNadrazene <> HierarchieRozdeleni.kodPodrizene) ';
//                break;
//            case 3:
//                $sqlPodrizene = 'and (HierarchieRozdeleni.kodPodrizene IN (SELECT Kod FROM Rozdeleni WHERE KodTypuRozdeleni = HierarchieRozdeleni.typNadrazene AND RozdeleniRodice = HierarchieRozdeleni.typNadrazene AND Rodic = HierarchieRozdeleni.kodNadrazene)) ';
//                break;
//        }
//
//        return
//            "EXISTS(SELECT RozdeleniOsob.RC FROM RozdeleniOsob JOIN HierarchieRozdeleni ON (HierarchieRozdeleni.typPodrizene = RozdeleniOsob.KodTypuRozdeleni AND HierarchieRozdeleni.kodPodrizene = RozdeleniOsob.Rozdeleni "
//            . "     AND HierarchieRozdeleni.typNadrazene = HierarchieRozdeleni.typPodrizene) "
//            . " where (RozdeleniOsob.RC = PracovniPomer.RC ) "
//            . "and (RozdeleniOsob.osobniCislo = PracovniPomer.osobniCislo )"
//            . "and (RozdeleniOsob.datumNastupu = PracovniPomer.datumNastupu ) "
//            . "and (RozdeleniOsob.KodTypuRozdeleni = " . (int)$typRozdeleni . ")"
//            . "and (HierarchieRozdeleni.kodNadrazene = '" . $this->database->addSlashes($rozdeleni) . "') "
//            . $sqlPodrizene
//            . 'and (RozdeleniOsob.PlatnostOd <= ' . $this->database->dateToString(RonPortalSession::getDatumDo() ?: time()) . ') '
//            . 'and ((RozdeleniOsob.PlatnostDo >= ' . $this->database->dateToString(RonPortalSession::getDatumOd() ?: time()) . ') or (RozdeleniOsob.PlatnostDo IS NULL))'
//            . ')';
//    }
}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2302_169.zip: ronportal/ronportal/zamestnanci/seznamppbrowser.php <==
<?php

/**
 * Pavel Rudol, RON Software
 *  4.9.2015
 */

namespace RonPortal\Zamestnanci;

use Ron\DB\SqlStatement;
use RonPortal\Prava;
use RonPortal\RozdeleniUtils;


///**
// * Class IDMediumFilterForm
// * @package Ron\RonPortal\Zamestnanci
// */
//class IDMediumField extends BrowserField
//{
//    private $volnaMedia;
//    private $vyrazenaMedia;
//
//    /**
//     * IDMediumFilterForm constructor.
//     * @param Database $database
//     * @param bool $volnaMedia
//     * @param $vyrazenaMedia
//     */
//    function __construct($database, $volnaMedia, $vyrazenaMedia)
//    {
//        parent::__construct($database);
//
//        $this->volnaMedia = $volnaMedia;
//        $this->vyrazenaMedia = $vyrazenaMedia;
//        $this->header = \Ron\ronText('identifikacni_medium');
//        $this->align = 'center';
//        $this->ordering = 1;
//    }
//
//    function getViewText($value, $rowNumber, $recordId, $rowData)
//    {
//        $result = '';
//
//        if($rowData[8] != ''){
//
//            if($this->volnaMedia) {
//                $result .=
//                    //Zobrazi odkaz v pripade ze jiz je karta k dane osobe pridelena
//                    '<a href="?menuid=zamestnanec&action=prirazenikarty&formaction=edit&volnamedia=' . ($this->vyrazenaMedia ? 1 : 0) . '&osoba=' . $rowData[0] . '&kodkarty=' . $rowData[7] .
//                    '&datumprideleni=' . $this->database->stringToTimestamp($rowData[9]) . '" >';
//                $result .= $rowData[8];
//                $result .= '</a>';
//            } else {
//                $result .=
//                    //Zobrazi odkaz v pripade ze jiz je karta k dane osobe pridelena
//                    '<a title="' . \Ron\ronText('nejsou_dalsi_volna_media') . '" href="?menuid=zamestnanec&action=prirazenikarty&formaction=edit&volnamedia=' . ($this->vyrazenaMedia ? 1 : 0) . '&osoba=' . $rowData[0] . '&kodkarty=' . $rowData[7] .
//                    '&datumprideleni=' . $this->database->stringToTimestamp($rowData[9]) . '" >';
//                $result .= $rowData[8];
//                $result .= '</a>';
//            }
//
//        }else {
//            if ($this->volnaMedia) {
//                $result .=
//                    '<a href="?menuid=zamestnanec&action=prirazenikarty&formaction=new&volnamedia=' . ($this->vyrazenaMedia ? 1 : 0) . '&osoba=' . $rowData[0] . '" >';
//                $result .= \Ron\ronText('vydani_media');
//                $result .= '</a>';
//            } elseif ($this->vyrazenaMedia) {
//                //$vyrazenaMedia
//                $result .= '<a title="' . \Ron\ronText('nejsou_volna_nebo_obnovit') . '" href="?menuid=zamestnanec&action=obnovenimedia&formaction=edit">' . \Ron\ronText('nejsou_volna_media') . '</a>';
//            } else {
//                $result .= '';
//            }
//        }
//        return $result;
//    }
//}

class SeznamPPBrowser extends SeznamZamestnancuBrowser
{
    public function __construct($database, $action)
    {
        parent::__construct($database, $action, true); // pracovni pomer = true

        $this->code = 'browserppomery';
        $this->tableId = 'browserppomery';

        $this->browserUrl = '?menuid=zamestnanec&action=seznampp&';

        //TODO: nechat, nebo uplne presunout do formulare zamestnance?
        /*global $enable_seznamPP;
        if ($enable_seznamPP)
        $this->addField(new IDMediumField($this->database, $this->dotazNaVolnaMedia(), $this->dotazNaVyrazenaMedia()));*/

    }


    public function loadColumnConfiguration($colSettings)
    {
        // kontrola, jestli neni zobrazeni sloupce v seznamu osob vypnuto
        if (isset($colSettings['pracovnipomery'])  &&  !$colSettings['pracovnipomery']) {
            return;
        }

        parent::loadColumnConfiguration($colSettings);
    }


    function getSQLFilter()
    {
        $params = $this ->database ->createParameters();

        $result = $this ->filterForm ->buildSqlFilter($params);

        $result .=
            ($result ? ' AND ' : '') .
            '(' . $this->pravaZobrazit->sqlFiltr('PracovniPomer', time(), time(), $params) . ')';

        if ($this ->filterForm instanceof SeznamZamestnancuFilterForm) {
            switch ($this->filterForm->getFilterValue('stavpp')) {
                case 'aktivni' :
                    $result .=
                        ' AND PracovniPomer.DatumNastupu <= ' . $params ->addDateParameter($this ->filterForm ->datumDo) .
                        ' AND ((PracovniPomer.DatumUkonceni >= ' . $params->addDateParameter($this ->filterForm ->datumOd) . ') OR (PracovniPomer.DatumUkonceni IS NULL))';
                    break;

                case 'neaktivni' :
                    $result .=
                        ' AND PracovniPomer.DatumUkonceni IS NOT NULL' .
                        ' AND (PracovniPomer.DatumUkonceni <= ' . $params->addDateParameter($this ->filterForm ->datumOd) . ')';
                    break;

                default :
            }

            if (isset($this ->filterForm ->typZamestnance)) {
                $result .=
                    ' AND (PracovniPomer.Zamestnanec = ' . $params ->addParameter((int)$this ->filterForm ->typZamestnance) . ')';
            }
        }

        if ($this ->filterForm ->kodTypuRozdeleni  &&  isset($this ->filterForm ->kodRozdeleni)) {
            $filtrRozdeleni1 = RozdeleniUtils::sqlFilterRozdeleniPP($this->database, 'PracovniPomer',
                $this ->filterForm ->kodTypuRozdeleni, $this ->filterForm ->kodRozdeleni,
                $this ->filterForm ->datumOd ?: time(), $this ->filterForm ->datumDo ?: time(),
                $this ->filterForm ->vcetnePodrizenychRozdeleni,
                $params);

            if ($filtrRozdeleni1) {
                $result .=
                    ($result ? ' AND ' : '') .
                    $filtrRozdeleni1;
            }

        }

        if ($this ->filterForm ->kodTypuRozdeleni2  &&  isset($this ->filterForm ->kodRozdeleni2)) {
            $filtrRozdeleni2 = RozdeleniUtils::sqlFilterRozdeleniPP($this->database, 'PracovniPomer',
                $this ->filterForm ->kodTypuRozdeleni2, $this ->filterForm ->kodRozdeleni2,
                $this ->filterForm ->datumOd ?: time(), $this ->filterForm ->datumDo ?: time(),
                $this ->filterForm ->vcetnePodrizenychRozdeleni2,
                $params);

            if ($filtrRozdeleni2) {
                $result .=
                    ($result ? ' AND ' : '') .
                    $filtrRozdeleni2;
            }

        }
//        if (RonPortalSettings::getIntValue(RonPortalSettings::ROZDELENI_TYP) != 0)
//            $result .= (RonPortalSession::rozdeleni() != '' ? 'AND ' . $this->getSQLFilterRozdeleni(RonPortalSettings::getIntValue(RonPortalSettings::ROZDELENI_TYP), RonPortalSession::rozdeleni(), RonPortalSession::rozdeleniVcetnePodrizenych()) : '');
//        if (RonPortalSettings::getIntValue(RonPortalSettings::ROZDELENI2_TYP) != 0)
//            $result .= (RonPortalSession::rozdeleni2() != '' ? 'AND ' . $this->getSQLFilterRozdeleni(RonPortalSettings::getIntValue(RonPortalSettings::ROZDELENI2_TYP), RonPortalSession::rozdeleni2(), RonPortalSession::rozdeleni2VcetnePodrizenych()) : '');

        return new SqlStatement($result, $params);
    }

//    /**
//     * @return bool
//     * @throws DBException
//     */
//    function dotazNaVolnaMedia()
//    {
//        $sql =
//            "SELECT  Karta.Kod, Karta.OznaceniMedia  FROM Karta LEFT JOIN S_ZpusobVyrazeniKarty ON (Karta.ZpusobVyrazeni = S_ZpusobVyrazeniKarty.Kod)" .
//            "WHERE DatumPorizeni <= " . $this->database->timestampToString(time()) .
//            "  AND (DatumVyrazeni >= " . $this->database->timestampToString(time()) . " OR DatumVyrazeni IS NULL)" .
//            " AND NOT EXISTS(SELECT kodKarty FROM PrirazeniKarty WHERE kodKarty = Karta.kod AND datumPrideleni <= " . $this->database->timestampToString(time()) .
//            "  AND (datumVraceni >= " . $this->database->timestampToString(time()) . " OR datumVraceni IS NULL))";
//
//        $cursor = $this->database->getSqlResult($sql);
//        $row = $cursor->fetch();
//
//        if (!$row) {
//            return false;
//        }
//        return true;
//    }
//
//    /**
//     * @return bool
//     * @throws DBException
//     */
//    function dotazNaVyrazenaMedia()
//    {
//        $sql =
//            'SELECT * FROM Karta WHERE DatumVyrazeni IS NOT NULL';
//
//        $cursor = $this->database->getSqlResult($sql);
//        $row = $cursor->fetch();
//
//        if (!$row) {
//            return false;
//        }
//        return true;
//    }

//    /**
//     *
//     * @param integer $typRozdeleni Typ rozdeleni pro filtrovani
//     * @param string $rozdeleni kod rozdeleni pro filtrovani
//     * @param int $vcetnePodrizenych 0=jen vlastni, 1=vcetne podrizenych, 2=jen podrizene, 3=jen primo podrizene
//     * @return string SQL podminka existence prirazeneho rozdeleni
//     */
//    function getSQLFilterRozdeleni($typRozdeleni, $rozdeleni, $vcetnePodrizenych)
//    {
//        $sqlPodrizene = '';
//
//        switch ($vcetnePodrizenych) {
//            case 0:
//                $sqlPodrizene = 'and (HierarchieRozdeleni.kodNadrazene = HierarchieRozdeleni.kodPodrizene) ';
//                break;
//            case 1:
//                $sqlPodrizene = '';
//                break;
//            case 2:
//                $sqlPodrizene = 'and (HierarchieRozdeleni.kodNadrazene <> HierarchieRozdeleni.kodPodrizene) ';
//                break;
//            case 3:
//                $sqlPodrizene = 'and (HierarchieRozdeleni.kodPodrizene IN (SELECT Kod FROM Rozdeleni WHERE KodTypuRozdeleni = HierarchieRozdeleni.typNadrazene AND RozdeleniRodice = HierarchieRozdeleni.typNadrazene AND Rodic = HierarchieRozdeleni.kodNadrazene)) ';
//                break;
//        }
//
//        return
//            "EXISTS(SELECT RozdeleniOsob.RC FROM RozdeleniOsob JOIN HierarchieRozdeleni ON (HierarchieRozdeleni.typPodrizene = RozdeleniOsob.KodTypuRozdeleni AND HierarchieRozdeleni.kodPodrizene = RozdeleniOsob.Rozdeleni "
//            . "     AND HierarchieRozdeleni.typNadrazene = HierarchieRozdeleni.typPodrizene) "
//            . " where (RozdeleniOsob.RC = PracovniPomer.RC ) "
//            . "and (RozdeleniOsob.osobniCislo = PracovniPomer.osobniCislo )"
//            . "and (RozdeleniOsob.datumNastupu = PracovniPomer.datumNastupu ) "
//            . "and (RozdeleniOsob.KodTypuRozdeleni = " . (int)$typRozdeleni . ")"
//            . "and (HierarchieRozdeleni.kodNadrazene = '" . $this->database->addSlashes($rozdeleni) . "') "
//            . $sqlPodrizene
//            . 'and (RozdeleniOsob.PlatnostOd <= ' . $this->database->dateToString(RonPortalSession::getDatumDo() ?: time()) . ') '
//            . 'and ((RozdeleniOsob.PlatnostDo >= ' . $this->database->dateToString(RonPortalSession::getDatumOd() ?: time()) . ') or (RozdeleniOsob.PlatnostDo IS NULL))'
//            . ')';
//    }
}
